#include "LocationNotifier.h"
#include <QDebug>

#define CHANGE_MARGIN 0.001

// Initialize all member variables to some valid value
LocationNotifier::LocationNotifier(QObject *parent)
    : QObject(parent), mLatitude(0), mLongitude(0), mLastNotifiedLatitude(0), mLastNotifiedLongitude(0)
{
    // Creates an source object which updates location changes at
    // regular intervals. This object is passed as parent for memory management
    mPositionInfoSource = QGeoPositionInfoSource::createDefaultSource(this);

    // Connects to it's position update signal
    connect(mPositionInfoSource, SIGNAL(positionUpdated(QGeoPositionInfo)), this, SLOT(positionUpdated(QGeoPositionInfo)));

    // Start updating every 5 seconds
    mPositionInfoSource->setUpdateInterval(5000);
    mPositionInfoSource->startUpdates();
}

void LocationNotifier::positionUpdated(const QGeoPositionInfo &info)
{
    // Get the coordinate from the incoming signal and
    // forward the notifications to the two API signals.
    QGeoCoordinate coordinate = info.coordinate();
    mLatitude = coordinate.latitude();
    mLongitude = coordinate.longitude();

    qDebug() << "Latitude:" << mLatitude << ", longitude:" << mLongitude;

    // Changes are notified only when change is big enough
    if (mLatitude > (mLastNotifiedLatitude + CHANGE_MARGIN) || mLatitude < (mLastNotifiedLatitude - CHANGE_MARGIN)) {
        mLastNotifiedLatitude = mLatitude;
        emit latitudeChanged(mLatitude);
    }
    if (mLongitude > (mLastNotifiedLongitude + CHANGE_MARGIN) || mLongitude < (mLastNotifiedLongitude - CHANGE_MARGIN)) {
        mLastNotifiedLongitude = mLongitude;
        emit longitudeChanged(mLongitude);
    }
}
