/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef EXAMPLEITEM_H
#define EXAMPLEITEM_H

#include <QtCore/QObject>
#include <QtCore/QString>
#include <QtCore/QTimer>

#include <QGeoPositionInfoSource>
#include <QGeoPositionInfo>
#include <QGeoCoordinate>

QTM_USE_NAMESPACE

class LocationNotifier : public QObject
{
    Q_OBJECT

    Q_PROPERTY(qreal latitude READ latitude NOTIFY latitudeChanged)
    Q_PROPERTY(qreal longitude READ longitude NOTIFY longitudeChanged)

public:
    LocationNotifier(QObject *parent = 0);

    qreal latitude() const { return mLatitude; }
    qreal longitude() const { return mLongitude; }

signals:
    void latitudeChanged(qreal newLat);
    void longitudeChanged(qreal newLong);

private slots:
    void positionUpdated(const QGeoPositionInfo &info);

private:
    qreal mLatitude;
    qreal mLongitude;
    qreal mLastNotifiedLatitude;
    qreal mLastNotifiedLongitude;
    QGeoPositionInfoSource *mPositionInfoSource;

    Q_DISABLE_COPY(LocationNotifier)
};

#endif // EXAMPLEITEM_H
